Welcome to the django-extensions documentation! — django-extensions 3.0.2 documentation

# Welcome to the django-extensions documentation!

Django Extensions is a collection of custom extensions for the Django Framework.

These include management commands, additional database fields, admin extensions and much more.

这篇文档当然还有中文版

# Getting Started

The easiest way to figure out what Django Extensions are all about is to watch the excellent screencast by Eric Holscher (Direct Vimeo link). In a couple minutes Eric walks you through a half a dozen command extensions.

# Getting it

You can get Django Extensions by using pip:

    $ pip install django-extensions

If you want to install it from source, grab the git repository and run setup.py:

    $ git clone git://github.com/django-extensions/django-extensions.git
    $ cd django-extensions
    $ python setup.py install

Then you will need to add the django_extensions application to the `INSTALLED_APPS` setting of your Django project settings.py file.

For more detailed instructions check out our Installation instructions. Enjoy.

# Compatibility with versions of Python and Django

We follow the Django guidelines for supported Python and Django versions. See more at Django Supported Versions

This might mean the django-extensions may work with older or unsupported versions but we do not guarantee it and most likely will not fix bugs related to incompatibilities with older versions.

# Contents

- Installation instructions
  - Installing
  - Development
  - Configuration
- Admin Extensions
  - Depreciation
  - Known Issues
  - Example Usage
- Command Extensions
  - shell_plus
  - create_template_tags
  - delete_squashed_migrations
  - dumpscript
  - RunScript
  - export_emails
  - generate_password
  - Graph models
  - list_model_info
  - list_signals
  - merge_model_instances
  - print_settings
  - RunProfileServer
  - RunServerPlus
  - sync_s3
  - syncdata
  - sqldiff
  - sqlcreate
  - sqldsn
  - validate_templates
  - admin_generator
- Command Signals
  - Basic Example
  - Custom Permissions For All Models
  - Using pre/post signals on your own commands
- Debugger Tags
  - Introduction
  - Usage
- Field Extensions
  - Current Database Model Field Extensions
- Jobs Scheduling
  - Setup
  - Create a job
  - Run a job
- Model Extensions
  - Introduction
  - Database Model Extensions
- Permissions
  - Introduction
  - Current Mixins
- Utilities
  - InternalIPS
- Validators
  - Usage
  - Current Database Model Field Extensions

# Indices and tables

- Search Page